SystemOrganization addCategory: #'EToysTests-Kernel'!

TextMorph subclass: #TextMorphTestable
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'EToysTests-Kernel'!

!TextMorphTestable commentStamp: 'mz 1/3/2007 22:27' prior: 0!
I am a thin extension of TextMorph, my added methods exist solely to support several SUnit tests where TextMorph participates.!

!TextMorphTestable methodsFor: 'testing' stamp: 'mz 1/2/2007 15:56'!
addOne
	"Assumes that current text represents a Number, and adds one to it."
self halt.
	self newContents: ((text asNumber + 1) asString).! !

TestCase subclass: #PlayerInteractionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'EToysTests-Kernel'!

!PlayerInteractionTest commentStamp: 'mz 1/14/2007 17:04' prior: 0!
I collect tests for various interactions between Morphs or Players, such as overlapping, seeing color, binding one Morph to another as action target, and other interactions.!

!PlayerInteractionTest methodsFor: 'initialize-release' stamp: 'mz 1/14/2007 16:45'!
setUp
	"Create members, if we need any during the test lifecycle."
	
	"ellipseMorph := EllipseMorph new."! !

!PlayerInteractionTest methodsFor: 'initialize-release' stamp: 'mz 1/14/2007 15:58'!
tearDown
	"Cleanup members created in setUp"
	
	" e.g. ellipseMorph delete."
! !

!PlayerInteractionTest methodsFor: 'testing' stamp: 'mz 1/14/2007 17:02'!
testColorSeesColor
	"Test if color is set and retrieved correctly on RectangleMorphs, and test if 'sees color' works in simple situations.
	This will be achieved by creating a blue and red rectangle, move them from overlapped to non-overlapped positions, and testing for 'sees color'. 
	This test has to have the rectangles opened in World, 
	    so we will put a large White Rectangle below, to ensure colors from world do not affect the 'sees' result.
	
	Note:  1) Points do not have to have Integer values, although there are interesting questions when displayed on real display. 
			   For example, does a blue Rectangle with bounds 0@0 corner: 49.5@49.5 display blue at pixel 50@50?.
			  This is not testing for such non-integer Morph positions.
		    2) This tests Morph>>#color: testColor sees: seenColor. 
		        TODO: Consider testing  Morph>>#color: testColor sees: seenColor, but it is a thin wrap only, so result should be same.
	"

	| rectWhite rectBlue rectRed |
	
	"Put a White large rectangle below both tested rectangles, to make sure no other color is below color-tested morphs"
	
	rectWhite := RectangleMorph new.
	rectWhite bounds: (0@0 corner: 500@500).
	rectWhite color: Color white.
	rectWhite borderWidth: 0.
	self assert: (rectWhite color = Color white).
	rectWhite openInWorld.	
	
	"Then create a Blue Rectangle, on top of it a Red Rectangle".
	
	rectBlue := RectangleMorph new.
	rectBlue bounds: (0@0 corner: 50@50).
	rectBlue color: Color blue.
	rectBlue borderWidth: 0.
	self assert: (rectBlue color = Color blue).
	self assert: (rectWhite bounds containsRect: (rectBlue bounds)). "Not under test, but want to make sure we have white below."
	rectBlue openInWorld.

	rectRed := RectangleMorph new.
	rectRed bounds: (45@45 corner: 70@70).
	rectRed color: Color red.
	rectRed borderWidth: 0.
	self assert: (rectRed color = Color red).
	self assert: (rectWhite bounds containsRect: (rectRed bounds)). "Not under test, but want to make sure we have white below."
	rectRed openInWorld.

	"Test color sees. First is gauge color, next is color to see"
	self assert: (rectRed color: Color red sees: Color blue).
	self assert: (rectRed color: Color red sees: Color red) not.
	
	"Move  rectRed, but it still overlaps by 2 pixels with blueRect"
	rectRed bounds: (49@49 corner: 70@70).
	self assert: (rectWhite bounds containsRect: (rectRed bounds)). "Not under test, but want to make sure we have white below."
	self assert: (rectRed color: Color red sees: Color blue).
	self assert: (rectRed color: Color red sees: Color red) not.

	"Move  rectRed, but it still overlaps by 1 pixel with blueRect."
	rectRed bounds: (50@50 corner: 70@70).
	self assert: (rectWhite bounds containsRect: (rectRed bounds)). "Not under test, but want to make sure we have white below."
	" redRect should STILL see Blue, but it does not - ###TODO### - should mark as 'expected failure'"
	self assert: (rectRed color: Color red sees: Color blue) not.
	self assert: (rectRed color: Color red sees: Color red) not.
	
	"Move rectRed , no overlap now."
	rectRed bounds: (51@51 corner: 70@70).
	self assert: (rectWhite bounds containsRect: (rectRed bounds)). "Not under test, but want to make sure we have white below."
	self assert: (rectRed color: Color red sees: Color blue) not.
	self assert: (rectRed color: Color red sees: Color red) not.
	
	"Finally 2 tests for white."
	self assert: (rectRed color: Color red sees: Color white).
	self assert: (rectBlue color: Color blue sees: Color white).
	
	"Cleanup stuff from World."
	rectRed delete.
	rectBlue delete.
	rectWhite delete.
	! !

!PlayerInteractionTest methodsFor: 'testing' stamp: 'mz 1/14/2007 16:44'!
testPlayerOverlap
	"Creates Ellipse and Rectangle, programatically moves their positions, check if Player>>#overlapsAny:player corresponds to expected result.
	We test position and overlap without opening in world. AssuredPlayer will add a player(UnscriptedPlayed) to the costume (EllipseMorph).
	"

	" Create a Ellipse=Circle and Rectangle."
	| player1 player2 |
	player1 := EllipseMorph new assuredPlayer.
	player1 costume bounds: (100@100 corner: 150@150). "both are in absolute world coordinates, so x-size=50"
	player1 costume position: 40@40. "move top-left corner to position 40@40, it can be calculated that Circle 's intersection with diagonal is at position 82@82."  
	"player1 costume openInWorld." "or - World addMorph: player1 costume."

	player2 := RectangleMorph new assuredPlayer.
	player2 costume bounds: (82@82 corner: 250@250).
	"player2 costume openInWorld."
	self assert: (player1 overlapsAny: player2) . "overlap by 1 pixel"
	
	player2 costume position: (player2 costume position + (1@1)). "Move by 1 pixel, now should not overlap"
	self assert:  (player2 costume position = (83@83)).
	self assert: (player1 overlapsAny: player2) not. " no overlap and they are different class (same class would always overlap)"
! !
